import "dart:html";

class DaySection
{  
  final String title;
  final String color;
  final String timeStart;
  final String timeEnd;
  const DaySection(this.title, this.color, this.timeStart, this.timeEnd);
}


class Day
{
  Day(this._date)
  {
    _content = new DivElement();
  }
  
  void setContent(String title, List<DaySection> sections)
  {    
    _content.children.clear();
    if (title == null) throw new ArgumentError.notNull("title");
    if (sections == null) throw new ArgumentError.notNull("sections");    
    _title = title;
    
    HeadingElement titleElement = new HeadingElement.h5();
    titleElement.innerHtml = _title;
    
    
    DivElement timeAreaElement = new DivElement();
    timeAreaElement.style.height = "480px"; /// one hour is 20px
    
    sections.forEach((DaySection section)
    {
      DateTime timeStart = _date.add(_date.difference(DateTime.parse(section.timeStart)));            
      DateTime timeEnd = _date.add(_date.difference(DateTime.parse(section.timeEnd)));
      
      int minutes = timeStart.difference(timeEnd).inMinutes;
      int sectionHeight = 20 * (minutes.toDouble() ~/ 60);
      
      DivElement sectionElement = new DivElement();
      sectionElement.style.position = "relative";
      sectionElement.style.display = "block";
      sectionElement.style.backgroundColor = section.color;
      sectionElement.style.height = sectionHeight.toString() + "px";      
      SpanElement timeStartElement = new SpanElement();
      SpanElement timeEndElement = new SpanElement();
      SpanElement sectionTitleElement = new SpanElement();      
      timeStartElement.innerHtml = timeStart.toIso8601String();
      timeEndElement.innerHtml = timeEnd.toIso8601String();
      sectionTitleElement.innerHtml = section.title;
      timeStartElement.style.pointerEvents = timeEndElement.style.position = sectionTitleElement.style.position = "absolute";
      timeStartElement.style.top = timeEndElement.style.bottom = "0";
      sectionTitleElement.style.top = "30px";
      sectionElement.children.add(timeStartElement);
      sectionElement.children.add(sectionTitleElement);
      sectionElement.children.add(timeEndElement);
      
      timeAreaElement.children.add(sectionElement);      
    });    
    
    _content.children.add(titleElement);
    _content.children.add(timeAreaElement);
  }  
  
  String _title;
  final DateTime _date;
  DivElement _content;
  DivElement get content => _content;
}
